@@ -134,10 +134,9 @@ def check_browser_versions():
 def searchweb(text,title):
     try:
         html = urllib.request.urlopen(text).read().decode("utf-8")
-        sys.excepthook = cef.ExceptHook  # To shutdown all CEF processes on error
+        sys.excepthook = cef.ExceptHook
         cef.Initialize()
-        cef.CreateBrowserSync(url=text,
-                              window_title=title)
+        cef.CreateBrowserSync(url=text,window_title=title)
         cef.MessageLoop()
     except:
         return -1
